qualia
======

.. image:: https://circleci.com/gh/darkfeline/qualia.svg?style=shield
   :target: https://circleci.com/gh/darkfeline/qualia
.. image:: https://codecov.io/gh/darkfeline/qualia/branch/master/graph/badge.svg
   :target: https://codecov.io/gh/darkfeline/qualia
